==> sociome_1.2.0.tar.gz: sociome/tests/testthat/test_arg_tibble_decennial1990.R <==
context("Test get_adi() calls for 1990 decennial")

test_get_adi_arg_tibble <- function(geography,
                                    dataset,
                                    year,
                                    geoid,
                                    state,
                                    county,
                                    zcta,
                                    ...) {
  exec_arg_tibble <-
    exec_arg_tibble(
      dataset,
      year, 
      geography = geography,
      geometry = FALSE,
      shift_geo = FALSE,
      cache_table = FALSE,
      key = NULL,
      ...
    )
  
  ref_area <-
    validate_location(
      geoid, 
      state, 
      county, 
      zcta, 
      geography, 
      dataset,
      exec_arg_tibble
    )
  
  tidyr::crossing(exec_arg_tibble, ref_area$state_county)
}


test_geoids <-
  c("01", "11", "39035", "39089", "09001010101", "09001010500", "090159025001")


vars1990 <-
  sociome::decennial_vars %>% 
  dplyr::filter(.data$year == 1990) %>%
  split(.$sumfile) %>% 
  lapply(dplyr::pull, var = "variable")


test_that("call tibble for geoids is correct", {
  
  expect_identical(
    test_get_adi_arg_tibble(
      geography = "state",
      dataset = "decennial",
      year = 1990,
      geoid = test_geoids,
      state = NULL,
      county = NULL,
      zcta = NULL
    ),
    tibble::tibble(
      .fn = list(tidycensus::get_decennial),
      variables = vars1990,
      sumfile = c("sf1", "sf3"),
      year = 1990,
      output = "tidy",
      keep_geo_vars = FALSE,
      geography = list("state"),
      geometry = list(FALSE),
      shift_geo = list(FALSE),
      cache_table = list(FALSE),
      key = list(NULL),
      state = list(c("01", "11", "39", "09"))
    )
  )
  
  expect_identical(
    test_get_adi_arg_tibble(
      geography = "county",
      dataset = "decennial",
      year = 1990,
      geoid = test_geoids,
      state = NULL,
      county = NULL,
      zcta = NULL
    ),
    tibble::tibble(
      .fn = list(tidycensus::get_decennial),
      variables = vars1990,
      sumfile = c("sf1", "sf3"),
      year = 1990,
      output = "tidy",
      keep_geo_vars = FALSE,
      geography = list("county"),
      geometry = list(FALSE),
      shift_geo = list(FALSE),
      cache_table = list(FALSE),
      key = list(NULL),
      state = list(c("01", "11", "39", "09"))
    )
  )
  
  expect_identical(
    test_get_adi_arg_tibble(
      geography = "tract",
      dataset = "decennial",
      year = 1990,
      geoid = test_geoids,
      state = NULL,
      county = NULL,
      zcta = NULL
    ),
    tibble::tibble(
      .fn = list(tidycensus::get_decennial),
      variables = purrr::lmap(vars1990, rep, 4),
      sumfile = c(rep("sf1", 4), rep("sf3", 4)),
      year = 1990,
      output = "tidy",
      keep_geo_vars = FALSE,
      geography = list("tract"),
      geometry = list(FALSE),
      shift_geo = list(FALSE),
      cache_table = list(FALSE),
      key = list(NULL),
      state = c("01", "09", "11", "39", "01", "09", "11", "39")
    )
  )
  
  
  skip_if(Sys.getenv("CENSUS_API_KEY") == "")
  
  
  expect_identical(
    test_get_adi_arg_tibble(
      geography = "block group",
      dataset = "decennial",
      year = 1990,
      geoid = test_geoids,
      state = NULL,
      county = NULL,
      zcta = NULL
    ),
    tibble::tibble(
      .fn = list(tidycensus::get_decennial),
      variables = purrr::lmap(vars1990, rep, 72),
      sumfile = c(rep("sf1", 72L), rep("sf3", 72L)),
      year = 1990,
      output = "tidy",
      keep_geo_vars = FALSE,
      geography = list("block group"),
      geometry = list(FALSE),
      shift_geo = list(FALSE),
      cache_table = list(FALSE),
      key = list(NULL),
      state =
        rep(
          c(rep("01", 67L), "09", "09", "11", "39", "39"),
          2L
        ),
      county =
        rep(
          c("001", "003", "005", "007", "009", "011", "013", "015", "017", "019", "021", "023", "025", "027", "029", "031", "033", "035", "037", "039", "041", "043", "045", "047", "049", "051", "053", "055", "057", "059", "061", "063", "065", "067", "069", "071", "073", "075", "077", "079", "081", "083", "085", "087", "089", "091", "093", "095", "097", "099", "101", "103", "105", "107", "109", "111", "113", "115", "117", "119", "121", "123", "125", "127", "129", "131", "133",
            "001", "015",
            "001",
            "035", "089"),
          2L
        )
    )
  )
})









test_that("call tibble for state only is correct", {

  expect_identical(
    test_get_adi_arg_tibble(
      geography = "state",
      dataset = "decennial",
      year = 1990,
      geoid = NULL,
      state = c("de", "dc", "ct"),
      county = NULL,
      zcta = NULL
    ),
    tibble::tibble(
      .fn = list(tidycensus::get_decennial),
      variables = vars1990,
      sumfile = c("sf1", "sf3"),
      year = 1990,
      output = "tidy",
      keep_geo_vars = FALSE,
      geography = list("state"),
      geometry = list(FALSE),
      shift_geo = list(FALSE),
      cache_table = list(FALSE),
      key = list(NULL),
      state = list(c("de", "dc", "ct")),
      county = list(NULL)
    )
  )

  expect_identical(
    test_get_adi_arg_tibble(
      geography = "county",
      dataset = "decennial",
      year = 1990,
      geoid = NULL,
      state = c("de", "dc", "ct"),
      county = NULL,
      zcta = NULL
    ),
    tibble::tibble(
      .fn = list(tidycensus::get_decennial),
      variables = vars1990,
      sumfile = c("sf1", "sf3"),
      year = 1990,
      output = "tidy",
      keep_geo_vars = FALSE,
      geography = list("county"),
      geometry = list(FALSE),
      shift_geo = list(FALSE),
      cache_table = list(FALSE),
      key = list(NULL),
      state = list(c("de", "dc", "ct")),
      county = list(NULL)
    )
  )

  expect_identical(
    test_get_adi_arg_tibble(
      geography = "tract",
      dataset = "decennial",
      year = 1990,
      geoid = NULL,
      state = c("de", "dc", "ct"),
      county = NULL,
      zcta = NULL
    ),
    tibble::tibble(
      .fn = list(tidycensus::get_decennial),
      variables = purrr::lmap(vars1990, rep, 3L),
      sumfile = c(rep("sf1", 3L), rep("sf3", 3L)),
      year = 1990,
      output = "tidy",
      keep_geo_vars = FALSE,
      geography = list("tract"),
      geometry = list(FALSE),
      shift_geo = list(FALSE),
      cache_table = list(FALSE),
      key = list(NULL),
      state = rep(c("ct", "dc", "de"), 2L)
    )
  )
  
  
  
  skip_if(Sys.getenv("CENSUS_API_KEY") == "")


  expect_identical(
    test_get_adi_arg_tibble(
      geography = "block group",
      dataset = "decennial",
      year = 1990,
      geoid = NULL,
      state = c("de", "dc", "ct"),
      county = NULL,
      zcta = NULL
    ),
    tibble::tibble(
      .fn = list(tidycensus::get_decennial),
      variables = purrr::lmap(vars1990, rep, 12L),
      sumfile = c(rep("sf1", 12L), rep("sf3", 12L)),
      year = 1990,
      output = "tidy",
      keep_geo_vars = FALSE,
      geography = list("block group"),
      geometry = list(FALSE),
      shift_geo = list(FALSE),
      cache_table = list(FALSE),
      key = list(NULL),
      state = 
        rep(
          c("09", "09", "09", "09", "09", "09", "09", "09", "10", "10", "10", "11"),
          2L
        ),
      county =
        rep(
          c("001", "003", "005", "007", "009", "011", "013", "015", "001", "003", "005", "001"),
          2L
        )
    )
  )

})




test_that("call tibble for one state and multiple counties is correct", {

  expect_identical(
    test_get_adi_arg_tibble(
      geography = "state",
      dataset = "decennial",
      year = 1990,
      geoid = NULL,
      state = "oh",
      county = c("cuyahoga", "erie", "franklin", "lake"),
      zcta = NULL
    ),
    tibble::tibble(
      .fn = list(tidycensus::get_decennial),
      variables = vars1990,
      sumfile = c("sf1", "sf3"),
      year = 1990,
      output = "tidy",
      keep_geo_vars = FALSE,
      geography = list("state"),
      geometry = list(FALSE),
      shift_geo = list(FALSE),
      cache_table = list(FALSE),
      key = list(NULL),
      state = list("oh"),
      county = list(c("cuyahoga", "erie", "franklin", "lake"))
    )
  )

  expect_identical(
    test_get_adi_arg_tibble(
      geography = "county",
      dataset = "decennial",
      year = 1990,
      geoid = NULL,
      state = "oh",
      county = c("cuyahoga", "erie", "franklin", "lake"),
      zcta = NULL
    ),
    tibble::tibble(
      .fn = list(tidycensus::get_decennial),
      variables = vars1990,
      sumfile = c("sf1", "sf3"),
      year = 1990,
      output = "tidy",
      keep_geo_vars = FALSE,
      geography = list("county"),
      geometry = list(FALSE),
      shift_geo = list(FALSE),
      cache_table = list(FALSE),
      key = list(NULL),
      state = list("oh"),
      county = list(c("cuyahoga", "erie", "franklin", "lake"))
    )
  )

  expect_identical(
    test_get_adi_arg_tibble(
      geography = "tract",
      dataset = "decennial",
      year = 1990,
      geoid = NULL,
      state = "oh",
      county = c("cuyahoga", "erie", "franklin", "lake"),
      zcta = NULL
    ),
    tibble::tibble(
      .fn = list(tidycensus::get_decennial),
      variables = purrr::lmap(vars1990, rep, 4L),
      sumfile = c(rep("sf1", 4L), rep("sf3", 4L)),
      year = 1990,
      output = "tidy",
      keep_geo_vars = FALSE,
      geography = list("tract"),
      geometry = list(FALSE),
      shift_geo = list(FALSE),
      cache_table = list(FALSE),
      key = list(NULL),
      state = rep("oh", 8L),
      county =
        rep(
          c("cuyahoga", "erie", "franklin", "lake"),
          2L
        )
    )
  )


  expect_identical(
    test_get_adi_arg_tibble(
      geography = "block group",
      dataset = "decennial",
      year = 1990,
      geoid = NULL,
      state = "oh",
      county = c("cuyahoga", "erie", "franklin", "lake"),
      zcta = NULL
    ),
    tibble::tibble(
      .fn = list(tidycensus::get_decennial),
      variables = purrr::lmap(vars1990, rep, 4L),
      sumfile = c(rep("sf1", 4L), rep("sf3", 4L)),
      year = 1990,
      output = "tidy",
      keep_geo_vars = FALSE,
      geography = list("block group"),
      geometry = list(FALSE),
      shift_geo = list(FALSE),
      cache_table = list(FALSE),
      key = list(NULL),
      state = rep("oh", 8L),
      county =
        rep(
          c("cuyahoga", "erie", "franklin", "lake"),
          2L
        )
    )
  )

})

==> sociome_1.3.2.tar.gz: sociome/tests/testthat/test_arg_tibble_decennial1990.R <==
context("Test get_adi() calls for 1990 decennial")

test_get_adi_arg_tibble <- function(geography,
                                    dataset,
                                    year,
                                    geoid,
                                    state,
                                    county,
                                    zcta,
                                    ...) {
  exec_arg_tibble <-
    exec_arg_tibble(
      dataset,
      year, 
      geography = geography,
      geometry = FALSE,
      shift_geo = FALSE,
      cache_table = FALSE,
      key = NULL,
      ...
    )
  
  ref_area <-
    validate_location(
      geoid, 
      state, 
      county, 
      zcta, 
      geography, 
      year,
      dataset,
      exec_arg_tibble
    )
  
  cross_args(exec_arg_tibble, ref_area$state_county, geography, year, dataset)
}


test_geoids <-
  c("01", "11", "39035", "39089", "09001010101", "09001010500", "090159025001")


vars1990 <-
  sociome::decennial_vars %>% 
  dplyr::filter(.data$year == 1990) %>%
  split(.$sumfile) %>% 
  lapply(dplyr::pull, var = "variable")


test_that("call tibble for geoids is correct", {
  
  expect_identical(
    test_get_adi_arg_tibble(
      geography = "state",
      dataset = "decennial",
      year = 1990,
      geoid = test_geoids,
      state = NULL,
      county = NULL,
      zcta = NULL
    ),
    tibble::tibble(
      .fn = list(tidycensus::get_decennial),
      geography = "state",variables = vars1990,
      sumfile = c("sf1", "sf3"),
      year = 1990,
      output = "tidy",
      keep_geo_vars = FALSE,
      geometry = list(FALSE),
      shift_geo = list(FALSE),
      cache_table = list(FALSE),
      key = list(NULL),
      state = list(c("01", "11", "39", "09"))
    )
  )
  
  expect_identical(
    test_get_adi_arg_tibble(
      geography = "county",
      dataset = "decennial",
      year = 1990,
      geoid = test_geoids,
      state = NULL,
      county = NULL,
      zcta = NULL
    ),
    tibble::tibble(
      .fn = list(tidycensus::get_decennial),
      geography = "county",variables = vars1990,
      sumfile = c("sf1", "sf3"),
      year = 1990,
      output = "tidy",
      keep_geo_vars = FALSE,
      geometry = list(FALSE),
      shift_geo = list(FALSE),
      cache_table = list(FALSE),
      key = list(NULL),
      state = list(c("01", "11", "39", "09"))
    )
  )
  
  expect_identical(
    test_get_adi_arg_tibble(
      geography = "tract",
      dataset = "decennial",
      year = 1990,
      geoid = test_geoids,
      state = NULL,
      county = NULL,
      zcta = NULL
    ),
    tibble::tibble(
      .fn = list(tidycensus::get_decennial),
      geography = "tract",variables = purrr::lmap(vars1990, rep, 4),
      sumfile = c(rep("sf1", 4), rep("sf3", 4)),
      year = 1990,
      output = "tidy",
      keep_geo_vars = FALSE,
      geometry = list(FALSE),
      shift_geo = list(FALSE),
      cache_table = list(FALSE),
      key = list(NULL),
      state = c("01", "09", "11", "39", "01", "09", "11", "39")
    )
  )
  
  
  skip_if(Sys.getenv("CENSUS_API_KEY") == "")
  
  
  expect_identical(
    test_get_adi_arg_tibble(
      geography = "block group",
      dataset = "decennial",
      year = 1990,
      geoid = test_geoids,
      state = NULL,
      county = NULL,
      zcta = NULL
    ),
    tibble::tibble(
      .fn = list(tidycensus::get_decennial),
      geography = "block group",variables = purrr::lmap(vars1990, rep, 72),
      sumfile = c(rep("sf1", 72L), rep("sf3", 72L)),
      year = 1990,
      output = "tidy",
      keep_geo_vars = FALSE,
      geometry = list(FALSE),
      shift_geo = list(FALSE),
      cache_table = list(FALSE),
      key = list(NULL),
      state =
        rep(
          c(rep("01", 67L), "09", "09", "11", "39", "39"),
          2L
        ),
      county =
        rep(
          c("001", "003", "005", "007", "009", "011", "013", "015", "017", "019", "021", "023", "025", "027", "029", "031", "033", "035", "037", "039", "041", "043", "045", "047", "049", "051", "053", "055", "057", "059", "061", "063", "065", "067", "069", "071", "073", "075", "077", "079", "081", "083", "085", "087", "089", "091", "093", "095", "097", "099", "101", "103", "105", "107", "109", "111", "113", "115", "117", "119", "121", "123", "125", "127", "129", "131", "133",
            "001", "015",
            "001",
            "035", "089"),
          2L
        )
    )
  )
})









test_that("call tibble for state only is correct", {

  expect_identical(
    test_get_adi_arg_tibble(
      geography = "state",
      dataset = "decennial",
      year = 1990,
      geoid = NULL,
      state = c("de", "dc", "ct"),
      county = NULL,
      zcta = NULL
    ),
    tibble::tibble(
      .fn = list(tidycensus::get_decennial),
      geography = "state",variables = vars1990,
      sumfile = c("sf1", "sf3"),
      year = 1990,
      output = "tidy",
      keep_geo_vars = FALSE,
      geometry = list(FALSE),
      shift_geo = list(FALSE),
      cache_table = list(FALSE),
      key = list(NULL),
      state = list(c("de", "dc", "ct")),
      county = list(NULL)
    )
  )

  expect_identical(
    test_get_adi_arg_tibble(
      geography = "county",
      dataset = "decennial",
      year = 1990,
      geoid = NULL,
      state = c("de", "dc", "ct"),
      county = NULL,
      zcta = NULL
    ),
    tibble::tibble(
      .fn = list(tidycensus::get_decennial),
      geography = "county",variables = vars1990,
      sumfile = c("sf1", "sf3"),
      year = 1990,
      output = "tidy",
      keep_geo_vars = FALSE,
      geometry = list(FALSE),
      shift_geo = list(FALSE),
      cache_table = list(FALSE),
      key = list(NULL),
      state = list(c("de", "dc", "ct")),
      county = list(NULL)
    )
  )

  expect_identical(
    test_get_adi_arg_tibble(
      geography = "tract",
      dataset = "decennial",
      year = 1990,
      geoid = NULL,
      state = c("de", "dc", "ct"),
      county = NULL,
      zcta = NULL
    ),
    tibble::tibble(
      .fn = list(tidycensus::get_decennial),
      geography = "tract",variables = purrr::lmap(vars1990, rep, 3L),
      sumfile = c(rep("sf1", 3L), rep("sf3", 3L)),
      year = 1990,
      output = "tidy",
      keep_geo_vars = FALSE,
      geometry = list(FALSE),
      shift_geo = list(FALSE),
      cache_table = list(FALSE),
      key = list(NULL),
      state = rep(c("ct", "dc", "de"), 2L)
    )
  )
  
  
  
  skip_if(Sys.getenv("CENSUS_API_KEY") == "")


  expect_identical(
    test_get_adi_arg_tibble(
      geography = "block group",
      dataset = "decennial",
      year = 1990,
      geoid = NULL,
      state = c("de", "dc", "ct"),
      county = NULL,
      zcta = NULL
    ),
    tibble::tibble(
      .fn = list(tidycensus::get_decennial),
      geography = "block group",variables = purrr::lmap(vars1990, rep, 12L),
      sumfile = c(rep("sf1", 12L), rep("sf3", 12L)),
      year = 1990,
      output = "tidy",
      keep_geo_vars = FALSE,
      geometry = list(FALSE),
      shift_geo = list(FALSE),
      cache_table = list(FALSE),
      key = list(NULL),
      state = 
        rep(
          c("09", "09", "09", "09", "09", "09", "09", "09", "10", "10", "10", "11"),
          2L
        ),
      county =
        rep(
          c("001", "003", "005", "007", "009", "011", "013", "015", "001", "003", "005", "001"),
          2L
        )
    )
  )

})




test_that("call tibble for one state and multiple counties is correct", {

  expect_identical(
    test_get_adi_arg_tibble(
      geography = "state",
      dataset = "decennial",
      year = 1990,
      geoid = NULL,
      state = "oh",
      county = c("cuyahoga", "erie", "franklin", "lake"),
      zcta = NULL
    ),
    tibble::tibble(
      .fn = list(tidycensus::get_decennial),
      geography = "state",variables = vars1990,
      sumfile = c("sf1", "sf3"),
      year = 1990,
      output = "tidy",
      keep_geo_vars = FALSE,
      geometry = list(FALSE),
      shift_geo = list(FALSE),
      cache_table = list(FALSE),
      key = list(NULL),
      state = list("oh"),
      county = list(c("cuyahoga", "erie", "franklin", "lake"))
    )
  )

  expect_identical(
    test_get_adi_arg_tibble(
      geography = "county",
      dataset = "decennial",
      year = 1990,
      geoid = NULL,
      state = "oh",
      county = c("cuyahoga", "erie", "franklin", "lake"),
      zcta = NULL
    ),
    tibble::tibble(
      .fn = list(tidycensus::get_decennial),
      geography = "county",variables = vars1990,
      sumfile = c("sf1", "sf3"),
      year = 1990,
      output = "tidy",
      keep_geo_vars = FALSE,
      geometry = list(FALSE),
      shift_geo = list(FALSE),
      cache_table = list(FALSE),
      key = list(NULL),
      state = list("oh"),
      county = list(c("cuyahoga", "erie", "franklin", "lake"))
    )
  )

  expect_identical(
    test_get_adi_arg_tibble(
      geography = "tract",
      dataset = "decennial",
      year = 1990,
      geoid = NULL,
      state = "oh",
      county = c("cuyahoga", "erie", "franklin", "lake"),
      zcta = NULL
    ),
    tibble::tibble(
      .fn = list(tidycensus::get_decennial),
      geography = "tract",variables = purrr::lmap(vars1990, rep, 4L),
      sumfile = c(rep("sf1", 4L), rep("sf3", 4L)),
      year = 1990,
      output = "tidy",
      keep_geo_vars = FALSE,
      geometry = list(FALSE),
      shift_geo = list(FALSE),
      cache_table = list(FALSE),
      key = list(NULL),
      state = rep("oh", 8L),
      county =
        rep(
          c("cuyahoga", "erie", "franklin", "lake"),
          2L
        )
    )
  )


  expect_identical(
    test_get_adi_arg_tibble(
      geography = "block group",
      dataset = "decennial",
      year = 1990,
      geoid = NULL,
      state = "oh",
      county = c("cuyahoga", "erie", "franklin", "lake"),
      zcta = NULL
    ),
    tibble::tibble(
      .fn = list(tidycensus::get_decennial),
      geography = "block group",variables = purrr::lmap(vars1990, rep, 4L),
      sumfile = c(rep("sf1", 4L), rep("sf3", 4L)),
      year = 1990,
      output = "tidy",
      keep_geo_vars = FALSE,
      geometry = list(FALSE),
      shift_geo = list(FALSE),
      cache_table = list(FALSE),
      key = list(NULL),
      state = rep("oh", 8L),
      county =
        rep(
          c("cuyahoga", "erie", "franklin", "lake"),
          2L
        )
    )
  )

})
